@@ -1,4 +1,4 @@
-/* $OpenBSD: b_sock.c,v 1.57 2014/10/13 02:39:09 bcook Exp $ */
+/* $OpenBSD: b_sock.c,v 1.60 2014/12/03 21:55:51 bcook Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -65,7 +65,6 @@
 #include <netinet/tcp.h>
 
 #include <errno.h>
-#include <fcntl.h>
 #include <limits.h>
 #include <netdb.h>
 #include <stdio.h>
@@ -94,8 +93,7 @@ BIO_get_host_ip(const char *str, unsigned char *ip)
 		goto err;
 	}
 
-	/* cast to short because of win16 winsock definition */
-	if ((short)he->h_addrtype != AF_INET) {
+	if (he->h_addrtype != AF_INET) {
 		BIOerr(BIO_F_BIO_GET_HOST_IP,
 		    BIO_R_GETHOSTBYNAME_ADDR_IS_NOT_AF_INET);
 		goto err;
@@ -194,17 +192,6 @@ BIO_gethostbyname(const char *name)
 	return gethostbyname(name);
 }
 
-int
-BIO_sock_init(void)
-{
-	return (1);
-}
-
-void
-BIO_sock_cleanup(void)
-{
-}
-
 int
 BIO_socket_ioctl(int fd, long type, void *arg)
 {
@@ -318,8 +305,7 @@ again:
 	if (bind_mode == BIO_BIND_REUSEADDR) {
 		int i = 1;
 
-		ret = setsockopt(s, SOL_SOCKET, SO_REUSEADDR, (char *)&i,
-		    sizeof(i));
+		ret = setsockopt(s, SOL_SOCKET, SO_REUSEADDR, &i, sizeof(i));
 		bind_mode = BIO_BIND_NORMAL;
 	}
 	if (bind(s, &server.sa, addrlen) == -1) {
@@ -456,14 +442,3 @@ BIO_set_tcp_ndelay(int s, int on)
 {
 	return (setsockopt(s, IPPROTO_TCP, TCP_NODELAY, &on, sizeof(on)) == 0);
 }
-
-int
-BIO_socket_nbio(int s, int mode)
-{
-	int flags = fcntl(s, F_GETFD);
-	if (mode && !(flags & O_NONBLOCK))
-		return (fcntl(s, F_SETFL, flags | O_NONBLOCK) != -1);
-	else if (!mode && (flags & O_NONBLOCK))
-		return (fcntl(s, F_SETFL, flags & ~O_NONBLOCK) != -1);
-	return (1);
-}
